const cmd = require('node-cmd');
const fs = require('fs');
let sharp = require('sharp');

let sitespeed = async (id, name, ip, callback_end, callback_update) => {
    // ./start.sh -n 1 --outputFolder /tmp/sitespeed https://malk.rocks
    // /start.sh --outputFolder /tmp/sitespeed -n 1 https://malk.rocks && /start-coach.sh -b firefox -f json  https://malk.rocks > /tmp/coach && sed '1,6d' /tmp/coach > /tmp/coachn
    let processRef = cmd.run( '/bin/bash /start.sh -v --outputFolder /tmp/sitespeed -n 1 ' + name );

    let sitespeed_folder_path = '/tmp/sitespeed/';

    let result_obj = {
        id: id,
        name: name,
        ip: ip,
        success: true,
        result: ''
    };

    processRef.stdout.on(
        'data',
        function(data) {

            const regex = /^.*(INFO|DEBUG): (.*?)$/gm;
            let m = regex.exec(data)

            if(
                data.indexOf("INFO:") || data.indexOf("DEBUG:")
            ){
                if(m !== null && m.length === 3){
                    result_obj.result = m[2];
                    callback_update(result_obj);
                }
            }
        }
    );

    let close_function = function(data){

        fs.readdir(sitespeed_folder_path + 'pages', (err, files) => {

            if(files.length === 0)
                return;

            let domain_folder_name = files[0];

            let pages_folder = 'pages/' + domain_folder_name + '/';
            let data_folder = pages_folder + 'data/';
            let screenshot_folder = data_folder + '/screenshots/1/';

            let index_file = 'index.html';
            let browsertime_file = 'browsertime.har';
            let screenshot_file = 'afterPageCompleteCheck.png';

            let coach_summary_file = sitespeed_folder_path + pages_folder + index_file;
            let sitespeed_summary_file = sitespeed_folder_path + index_file;
            let browsertime_summary_file = sitespeed_folder_path + data_folder + browsertime_file;
            let screenshot_file_with_path = sitespeed_folder_path + screenshot_folder + screenshot_file;

            if (
                fs.existsSync(browsertime_summary_file) &&
                fs.existsSync(sitespeed_summary_file) &&
                fs.existsSync(coach_summary_file)
            ) {

                // browsertime start
                let data_1 = fs.readFileSync(browsertime_summary_file, 'utf8');

                // summary start
                let index_file_parser = new (require( __dirname + '/src/parser/parser_index'))(sitespeed_summary_file);
                // summary end

                // Coach start
                let coach_file_parser = new (require( __dirname + '/src/parser/parser_coach'))(coach_summary_file);
                // Coach end

                sharp(screenshot_file_with_path)
                    .rotate()
                    .resize(400)
                    .toBuffer()
                    .then( async (data) => {

                        let base64 = data.toString('base64');

                        let return_json = {
                            summary: (await index_file_parser.get()),
                            coach: (await coach_file_parser.get()),
                            browsertime: JSON.parse(data_1),
                            image: 'data:image/png;base64,' + base64
                        };

                        result_obj.result = return_json
                        fs.rmSync('/tmp/sitespeed', { recursive: true });
                        callback_end(result_obj);
                    })
                    .catch( err => {
                        console.log(err);
                    });
            }else{
                console.log('Files not found.');
                callback_end({
                    success: false,
                    message: 'Error occurred. Try again later.'
                });
            }
        });

    }

    processRef.stdout.on(
        'close',
        close_function
    );
}
module.exports = sitespeed;
