let Parser = require('./parser');

class CoachFileParser extends Parser{

    async getHeader(){
        let html = await this.getFileHtml();

        let head = html.querySelector('#coach-panel')
            .querySelector('.row')
            .querySelector('.column')
            .querySelector('.row')
            .querySelector('.eight')
            .querySelector('ul')
            .querySelectorAll('li');

        return {
            'Total score': head[0].querySelector('span').rawText.trim(),
            'Performance score': head[1].querySelector('span').rawText.trim(),
            'Privacy score': head[2].querySelector('span').rawText.trim(),
            'Best practice score': head[3].querySelector('span').rawText.trim()
        };
    }

    async getIndexHtml(index){
        let html = await this.getFileHtml();
        return html.querySelector('#coach-panel').querySelectorAll('.responsive')[index];
    }

    async getIndexHtmlLength(){
        let html = await this.getFileHtml();
        return html.querySelector('#coach-panel').querySelectorAll('.responsive').length;
    }

    async getIndexHeader(index){
        const regex = /^(.*?) \((.*?)\)/gm;
        let html = await this.getFileHtml();
        let str = html.querySelector('#coach-panel').querySelectorAll('h3')[index + 1].rawText;
        let m = regex.exec(str)

        return {
            title: m[1],
            score: m[2]
        };
    }

    async getIndex(index){
        let page_data_json = [];
        let current_object = {};
        let k = 0;

        let index_html = await this.getIndexHtml(index);

        for (let v of index_html.querySelector('tbody').querySelectorAll('tr')) {

            if(v.classNames === 'odd' || v.classNames === 'even'){

                if(Object.keys(current_object).length > 0){
                    page_data_json.push(current_object);
                    current_object = {};
                }

                v.querySelectorAll('td').forEach(function(td){
                    current_object[td.getAttribute('data-title')] = td.rawText.toString();
                });

            }else if(v.classNames === 'u-hideable'){

                let element_title = v.querySelector('td').querySelector('b').rawText.toString();

                if(element_title.indexOf('Offenders') >= 0) {
                    current_object['Offenders'] = [];

                    v.querySelector('td').querySelectorAll('li').forEach(function (li) {
                        if (li.querySelector('a') === null) {
                            current_object['Offenders'].push(
                                li.rawText
                            );
                        } else {
                            current_object['Offenders'].push(
                                li.querySelector('a').getAttribute('href')
                            );
                        }
                    });

                }else if(element_title.indexOf('Description') >= 0){
                    current_object['Description'] = v.querySelector('i').rawText;
                }
            }

            if(k === index_html.querySelector('tbody').querySelectorAll('tr').length - 1){
                page_data_json.push(current_object);
            }

            k++;
        }

        return page_data_json;
    }

    async get(){
        let detail_array = [];

        for(let i = 0;i < (await this.getIndexHtmlLength());i++){
            detail_array.push({
                'header': (await this.getIndexHeader(i)),
                'data': (await this.getIndex(i))
            });
        }
        return {
            'score': (await this.getHeader()),
            'result': detail_array
        };
    }

}
module.exports = CoachFileParser;

